==> qtjambi-qt3danimation-jre8-5.15.4-sources.jar: io/qt/qt3d/animation/QClipAnimator.java <==
package io.qt.qt3d.animation;


/**
 * <p>Component providing simple animation playback capabilities</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qclipanimator.html">Qt3DAnimation::QClipAnimator</a></p>
 */
public class QClipAnimator extends io.qt.qt3d.animation.QAbstractClipAnimator
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QClipAnimator.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qclipanimator.html#clip-prop">Qt3DAnimation::QClipAnimator::clipChanged(Qt3DAnimation::QAbstractAnimationClip*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="clip")
    public final Signal1<io.qt.qt3d.animation.QAbstractAnimationClip> clipChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QClipAnimator(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QClipAnimator() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QClipAnimator(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QClipAnimator instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qclipanimator.html#clip-prop">Qt3DAnimation::QClipAnimator::clip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="clip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractAnimationClip clip(){
        return clip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractAnimationClip clip_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qclipanimator.html#clip-prop">Qt3DAnimation::QClipAnimator::setClip(Qt3DAnimation::QAbstractAnimationClip*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="clip")
    public final void setClip(io.qt.qt3d.animation.QAbstractAnimationClip clip){
        setClip_native_Qt3DAnimation_QAbstractAnimationClip_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(clip));
    }
    
    private native void setClip_native_Qt3DAnimation_QAbstractAnimationClip_ptr(long __this__nativeId, long clip);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QClipAnimator(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QClipAnimator(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QClipAnimator instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3danimation-jre8-6.2.2-sources.jar: io/qt/qt3d/animation/QClipAnimator.java <==
package io.qt.qt3d.animation;


/**
 * <p>Component providing simple animation playback capabilities</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qclipanimator.html">Qt3DAnimation::QClipAnimator</a></p>
 */
public class QClipAnimator extends io.qt.qt3d.animation.QAbstractClipAnimator
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QClipAnimator.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qclipanimator.html#clip-prop">Qt3DAnimation::QClipAnimator::clipChanged(Qt3DAnimation::QAbstractAnimationClip*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="clip")
    public final Signal1<io.qt.qt3d.animation.QAbstractAnimationClip> clipChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QClipAnimator(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QClipAnimator() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QClipAnimator(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QClipAnimator instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qclipanimator.html#clip-prop">Qt3DAnimation::QClipAnimator::clip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="clip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractAnimationClip clip(){
        return clip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractAnimationClip clip_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qclipanimator.html#clip-prop">Qt3DAnimation::QClipAnimator::setClip(Qt3DAnimation::QAbstractAnimationClip*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="clip")
    public final void setClip(io.qt.qt3d.animation.QAbstractAnimationClip clip){
        setClip_native_Qt3DAnimation_QAbstractAnimationClip_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(clip));
    }
    
    private native void setClip_native_Qt3DAnimation_QAbstractAnimationClip_ptr(long __this__nativeId, long clip);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QClipAnimator(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QClipAnimator(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QClipAnimator instance, QDeclarativeConstructor constructor);
    
}
